@@ -1,6 +1,4 @@
-/* $RCSfile: dmake.c,v $
--- $Revision: 1.12.2.4 $
--- last change: $Author: vq $ $Date: 2008/02/07 15:42:37 $
+/*
 --
 -- SYNOPSIS
 --      The main program.
@@ -67,7 +65,7 @@
 -- 
 --      This program is NOT free software; you can redistribute it and/or
 --      modify it under the terms of the Software License Agreement Provided
---      in the file <distribution-root>/readme/license.txt.
+--      in the file <distribution-root>/COPYING.
 --
 -- LOG
 --      Use cvs log to obtain detailed change logs.
@@ -106,7 +104,9 @@
 #endif
 #define ARG(a,b) a b
 
-static char *sccid = "Copyright (c) 1990,...,1997 by WTI Corp.";
+#define SCCID "Copyright (c) 1990,...,1997 by WTI Corp.\n" \
+              "Licensed under the GPLv1\n" \
+              "https://jimjag.github.io/dmake/"
 static char _warn  = TRUE;		/* warnings on by default */
 
 static	void	_do_VPATH();
@@ -116,6 +116,9 @@ static  void    _do_f_flag ANSI((char, char *, char **));
 #else
 static  void    _do_f_flag ANSI((int, char *, char **));
 #endif
+#ifdef _WIN32
+static  int     dm_malloc_handler(size_t size);
+#endif
 
 PUBLIC int
 main(argc, argv)
@@ -137,6 +140,10 @@ char **argv;
    int     ex_val;
    int     m_export;
 
+#ifdef _WIN32
+   dm_set_new_handler(dm_malloc_handler);
+#endif
+
    /* Uncomment the following line to pass commands to the DBUG engine
     * before the command line switches (-#..) are evaluated. */
    /*
@@ -173,9 +180,11 @@ char **argv;
    Trace     = FALSE;
    Touch     = FALSE;
    Check     = FALSE;
-   Microsoft = FALSE;
+/* Microsoft = FALSE; */
    Makemkf   = FALSE;
+#if defined(__CYGWIN__)
    UseWinpath= FALSE;
+#endif
    No_exec   = FALSE;
    m_export  = FALSE;
    cmdmacs   = NIL(char);
@@ -292,7 +301,7 @@ char **argv;
                  HASHPTR hp;
                  /* This cleans the .SILENT setting */
                  hp = Def_macro(".SILENT", "", M_EXPANDED);
-                 /* This overrides the bitmask for further occurences of
+                 /* This overrides the bitmask for further occurrences of
                   * .SILENT to "no bits allowed", see bit variables in the
                   * set_macro_value() definition in dag.c.
                   * The bitmask is already set by Create_macro_vars() in
@@ -380,16 +389,19 @@ char **argv;
    _warn = TRUE;
 
    /* If -r was not given find and parse startup-makefile. */
-   if( Rules ) {
-      char *fname;
+   if( Rules )
+   {
+     char *fname = NIL(char);
 
-      /* Search_file() also checks the environment variable. */
-      if( (mkfil=Search_file("MAKESTARTUP", &fname)) != NIL(FILE) ) {
-         Parse(mkfil);
-	 Def_macro( "MAKESTARTUP", fname, M_EXPANDED|M_MULTI|M_FORCE );
-      }
-      else
-         Fatal( "Configuration file `%s' not found", fname );
+     /* Search_file() also checks the environment variable. */
+     if( (mkfil=Search_file("MAKESTARTUP", &fname)) != NIL(FILE) )
+     {
+       Parse(mkfil);
+       Def_macro( "MAKESTARTUP", fname, M_EXPANDED|M_MULTI|M_FORCE );
+     }
+     else
+       Fatal( "Configuration file `%s' not found", fname );
+     if ( fname != NIL(char)) { FREE( fname ); fname = NIL(char); }
    }
 
    /* Define the targets set on the command line now. */
@@ -428,8 +440,7 @@ char **argv;
       char *p;
 
       if( strcmp(f, "stdin") == 0 ) f = "-";
-      p = DmStrAdd( "-f", f, FALSE );
-      Def_macro( "MAKEFILE", p, M_PRECIOUS|M_NOEXPORT );
+      Def_macro( "MAKEFILE", p = DmStrAdd( "-f", f, FALSE ), M_PRECIOUS|M_NOEXPORT ); FREE(p);
       Parse( mkfil );
    }
    else if( !Rules )
@@ -588,7 +599,7 @@ int  err;
       fil = fopen( name, mode ? "w":"r" );
 
    if( Verbose & V_FILE_IO )
-      printf( "%s:  Openning [%s] for %s", Pname, name, mode?"write":"read" );
+      printf( "%s:  Opening [%s] for %s", Pname, name, mode?"write":"read" );
 
    if( fil == NIL(FILE) ) {
       if( Verbose & V_FILE_IO ) printf( " (fail)\n" );
@@ -663,23 +674,25 @@ char **rname;
     */
 
    if( (hp = GET_MACRO(macname)) != NIL(HASH) ) {
-      /* Only expand if needed. */
-      if( hp->ht_flag & M_EXPANDED ) {
-	 ename = fname = DmStrDup(hp->ht_value);
-      } else {
-	 ename = fname = Expand(hp->ht_value);
-      }
+     /* Only expand if needed. */
+     if( hp->ht_flag & M_EXPANDED ) {
+       ename = fname = DmStrDup(hp->ht_value);
+     } else {
+       ename = fname = Expand(hp->ht_value);
+     }
 
-      if( hp->ht_flag & M_PRECIOUS ) fil = Openfile(fname, FALSE, FALSE);
+     if( hp->ht_flag & M_PRECIOUS ) fil = Openfile(fname, FALSE, FALSE);
    }
 
    if( fil == NIL(FILE) ) {
-      fname=Expand(Read_env_string(macname));
-      if( (fil = Openfile(fname, FALSE, FALSE)) != NIL(FILE) ) FREE(ename);
+     fname=Expand(Read_env_string(macname));
+     if( (fil = Openfile(fname, FALSE, FALSE)) != NIL(FILE) ) FREE(ename);
    }
 
-   if( fil == NIL(FILE) && hp != NIL(HASH) )
-      fil = Openfile(fname=ename, FALSE, FALSE);
+   if( fil == NIL(FILE) && hp != NIL(HASH) ) {
+     if ( fname != NIL(char) ) { FREE(fname); fname = NIL(char); }
+     fil = Openfile(fname=ename, FALSE, FALSE);
+   }
 
    if( rname ) *rname = fname;
 
@@ -850,12 +863,20 @@ DARG(va_alist_type,va_alist)
    va_end(args);
 }
 
-
+#ifdef _WIN32
+static int
+dm_malloc_handler(size_t size)
+{
+   Fatal( "No more memory" );
+   return 0;
+}
+#else
 PUBLIC void
 No_ram()
 {
    Fatal( "No more memory" );
 }
+#endif
 
 
 PUBLIC void
@@ -925,6 +946,7 @@ int eflag;
    puts("    -x   - export macro values to environment");
    puts("    -X   - ignore #! lines at start of makefile");
    }
+   FREE(fill);
 
    Quit(0);
 }
@@ -936,24 +958,24 @@ Version()
    extern char **Rule_tab;
    char **p;
    
-   printf("%s - Version %s (%s)\n", Pname, VERSION, BUILDINFO);
-   printf("%s\n\n", sccid);
+   printf("%s - Version " VERSION " (" BUILDINFO ")\n"
+          SCCID "\n\n"
+          "Default Configuration:\n"
+          , Pname);
 
-   puts("Default Configuration:");
    for (p=Rule_tab;  *p != NIL(char);  p++)
       printf("\t%s\n", *p);
 
-   printf("\n");
-
+   puts("\n"
 #if defined(HAVE_SPAWN_H) || defined(__CYGWIN__)
    /* Only systems that have spawn ar concerned whether spawn or fork/exec
     * are used. */
 #if ENABLE_SPAWN
-      printf("Subprocesses are executed using: spawn.\n\n");
+      "Subprocesses are executed using: spawn.\n\n"
 #else
-      printf("Subprocesses are executed using: fork/exec.\n\n");
+      "Subprocesses are executed using: fork/exec.\n\n"
 #endif
 #endif
 
-      printf("Please read the NEWS file for the latest release notes.\n");
+      "Please read the CHANGES.md file for the latest release notes.");
 }
