@@ -1,6 +1,4 @@
-/* $RCSfile: function.c,v $
--- $Revision: 1.11.2.2 $
--- last change: $Author: vq $ $Date: 2008/02/07 19:50:01 $
+/*
 --
 -- SYNOPSIS
 --      GNU style functions for dmake.
@@ -21,7 +19,7 @@
 --
 --      This program is NOT free software; you can redistribute it and/or
 --      modify it under the terms of the Software License Agreement Provided
---      in the file <distribution-root>/readme/license.txt.
+--      in the file <distribution-root>/COPYING.
 --
 -- LOG
 --      Use cvs log to obtain detailed change logs.
@@ -80,7 +78,7 @@ char *buf;
       }
    }
 
-   /* ??? Some function macros expect comma seperated parameters, but
+   /* ??? Some function macros expect comma separated parameters, but
     * no decent parser is included. The desirable solution would be
     * to parse fname for the correct number of parameters in fname
     * when a function is recognized. We only count the parameters
@@ -115,7 +113,7 @@ char *buf;
 	    if( mod_count == 2 )
 	      res = _exec_iseq(mod1,mod2,args,TRUE);
 	    else
-	      Fatal( "Two comma-seperated arguments expected in [%s].\n", buf );
+	      Fatal( "Two comma-separated arguments expected in [%s].\n", buf );
 	 else if (strncmp(fname,"echo",4) == 0)
 	    res = _exec_echo(args);
          else
@@ -127,7 +125,7 @@ char *buf;
 	    if( mod_count == 2 )
 	      res = _exec_foreach(mod1,mod2,args);
 	    else
-	      Fatal( "Two comma-seperated arguments expected in [%s].\n", buf );
+	      Fatal( "Two comma-separated arguments expected in [%s].\n", buf );
 	 else
 	    res = _exec_call(fname,args);
 	 break;
@@ -137,7 +135,7 @@ char *buf;
 	    if( mod_count < 3 )
 	      res = _exec_mktmp(mod1,mod2,args);
 	    else
-	      Fatal( "Maximal two comma-seperated arguments expected in [%s].\n", buf );
+	      Fatal( "Maximal two comma-separated arguments expected in [%s].\n", buf );
 	 else
 	    res = _exec_call(fname,args);
 	 break;
@@ -158,6 +156,7 @@ char *buf;
 	       res = exec_normpath(eargs);
 	    }
 	    else if( mod_count == 1 ) {
+#if defined(__CYGWIN__)
 	       char *para = Expand(mod1);
 	       int tmpUseWinpath = UseWinpath;
 
@@ -166,12 +165,15 @@ char *buf;
 	       } else {
 		  UseWinpath = TRUE;
 	       }
+#endif
 	       res = exec_normpath(eargs);
+#if defined(__CYGWIN__)
 	       UseWinpath = tmpUseWinpath;
 	       FREE(para);
+#endif
 	    }
 	    else
-	       Fatal( "One or no comma-seperated arguments expected in [%s].\n", buf );
+	       Fatal( "One or no comma-separated arguments expected in [%s].\n", buf );
 
 	    FREE(eargs);
 	 }
@@ -186,7 +188,7 @@ char *buf;
 	    if( mod_count == 2 )
 	      res = _exec_iseq(mod1,mod2,args,FALSE);
 	    else
-	      Fatal( "Two comma-seperated arguments expected in [%s].\n", buf );
+	      Fatal( "Two comma-separated arguments expected in [%s].\n", buf );
 	 else
 	    res = _exec_call(fname,args);
 	 break;
@@ -214,14 +216,14 @@ char *buf;
 	       FREE(emod);		  
 	    }
 	    else
-	       Fatal( "One or no comma-seperated arguments expected in [%s].\n", buf );
+	       Fatal( "One or no comma-separated arguments expected in [%s].\n", buf );
 	 else if(strncmp(fname,"strip",5)==0)
 	    res = Tokenize(Expand(args)," ",'t',TRUE);
 	 else if(strncmp(fname,"subst",5)==0) {
 	    if( mod_count == 2 )
 	      res = _exec_subst(mod1,mod2,args);
 	    else
-	      Fatal( "Two comma-seperated arguments expected in [%s].\n", buf );
+	      Fatal( "Two comma-separated arguments expected in [%s].\n", buf );
 	 }
          else
             res = _exec_call(fname,args);
@@ -465,45 +467,45 @@ static char *
 _exec_uniq( args )
 char *args;
 {
-   char *res  = NIL(char);
-   char *data = Expand(args);
-   char **tokens;
-   char **tokens_after;
-   char *p;
-   char *white = " \t\n";
-   int  j;
-   int  i;
-   char *last = "";
-   int  k = 0;
+  char *res  = NIL(char);
+  char *data = Expand(args);
+  char **tokens;
+  char **tokens_after;
+  char *p;
+  char *white = " \t\n";
+  int  j;
+  int  i;
+  char *last = "";
+  int  k = 0;
 
-   for(i=0,p=DmStrSpn(data,white);*p;p=DmStrSpn(DmStrPbrk(p,white),white),i++);
+  for(i=0,p=DmStrSpn(data,white);*p;p=DmStrSpn(DmStrPbrk(p,white),white),i++);
 
-   if( i != 0 ) {
-      TALLOC(tokens, i, char *);
-      TALLOC(tokens_after, i, char *);
+  if( i != 0 ) {
+    TALLOC(tokens, i, char *);
+    TALLOC(tokens_after, i, char *);
 
-      for( i=0,p=DmStrSpn(data,white); *p; p=DmStrSpn(p,white),i++){
-         tokens[i] = p;
-         p = DmStrPbrk(p,white);
-         if( *p ) *p++ = '\0';
-      }
+    for( i=0,p=DmStrSpn(data,white); *p; p=DmStrSpn(p,white),i++){
+      tokens[i] = p;
+      p = DmStrPbrk(p,white);
+      if( *p ) *p++ = '\0';
+    }
 
-      qsort( tokens, i, sizeof(char *), _mystrcmp );
+    qsort( tokens, i, sizeof(char *), _mystrcmp );
 
-      for( j=0; j<i; j++ ) {
-	 if (strcmp(tokens[j], last) != 0) {
+    for( j=0; j<i; j++ ) {
+      if (strcmp(tokens[j], last) != 0) {
 		tokens_after[k++] = tokens[j];
 		last = tokens[j];
-	 }
       }
+    }
 
-      for( j=0; j<k; j++ ) res = DmStrApp(res, tokens_after[j]);
-      FREE(data);
-      FREE(tokens);
-      FREE(tokens_after);
-   }
+    for( j=0; j<k; j++ ) res = DmStrApp(res, tokens_after[j]);
+    FREE(tokens);
+    FREE(tokens_after);
+  }
 
-   return(res);
+  FREE(data);
+  return(res);
 }
 
 static int
@@ -587,7 +589,7 @@ int expand;
       Do_profile_output( "s", M_TARGET, &cell );
 
    /* Print the shell escape command. */
-   if( !(rcp.st_attr & A_SILENT) ) {
+   if( Verbose & V_FORCEECHO ) {
       printf( "%s: Executing shell macro: %s\n", Pname, data );
       fflush(stdout);
    }
