@@ -1,4 +1,4 @@
-/* RCS  $Id: imacs.c,v 1.8.2.2 2007/11/12 00:12:02 vq Exp $
+/* RCS  $Id: imacs.c,v 1.9 2008-03-05 18:29:01 kz Exp $
 --
 -- SYNOPSIS
 --      Define default internal macros.
@@ -20,7 +20,7 @@
 -- 
 --      This program is NOT free software; you can redistribute it and/or
 --      modify it under the terms of the Software License Agreement Provided
---      in the file <distribution-root>/readme/license.txt.
+--      in the file <distribution-root>/COPYING.
 --
 -- LOG
 --      Use cvs log to obtain detailed change logs.
@@ -28,7 +28,13 @@
 
 #include "extern.h"
 
+#define DM_StGiFy(a)	#a
+#define STRINGIFY(a)	DM_StGiFy(a)
+#define SET_INT_VAR_FROM_INT(name, val, flag, var) _set_int_var_from_int_and_str(name, val, STRINGIFY(val), flag, var)
+
 static	void	_set_int_var ANSI((char *, char *, int, int *));
+static	void	_set_int_var_from_int_and_str ANSI((char *, int, char *, int, int *));
+static	void	_set_bool_var ANSI((char *, int, int, char *));
 static	void	_set_string_var ANSI((char *, char *, int, char **));
 static	void	_set_bit_var ANSI((char *, char *, int));
 
@@ -68,7 +74,7 @@ Create_macro_vars()
    else
 #if (_MPW)
    	  DirSepStr = ":";
-#elif defined( __EMX__)
+#elif defined( __EMX__BACKSLASH)
    /* Use '\' for OS/2 port. */
    	  DirSepStr = "\\";
 #else
@@ -104,18 +110,19 @@ Create_macro_vars()
    _set_string_var("GROUPFLAGS",   " ", M_DEFAULT, &GShell_flags);
    _set_string_var("SHELLMETAS",   "",  M_DEFAULT, &Shell_metas );
    _set_string_var("GROUPSUFFIX",  "",  M_DEFAULT, &Grp_suff    );
-   _set_string_var("AUGMAKE",NIL(char), M_DEFAULT, &Augmake     );
-   _set_string_var("OOODMAKEMODE", "",  M_DEFAULT, &OOoDmMode );
+   _set_bool_var  ("AUGMAKE",     FALSE,M_DEFAULT, &Augmake     );
+   _set_bool_var  ("OOODMAKEMODE",FALSE,M_DEFAULT, &OOoDmMode );
    _set_string_var(".KEEP_STATE",  "",  M_DEFAULT, &Keep_state  );
    _set_string_var(".NOTABS",      "",  M_MULTI, &Notabs );
-   _set_string_var(".DIRCACHE",    "y", M_DEFAULT, &UseDirCache );
+   _set_bool_var  (".DIRCACHE",   TRUE, M_DEFAULT, &UseDirCache );
 
 #if CASE_INSENSITIVE_FS
-#define DIRCACHERESPCASEDEFAULT ""
+#define DIRCACHERESPCASEDEFAULT FALSE
 #else
-#define DIRCACHERESPCASEDEFAULT "y"
+#define DIRCACHERESPCASEDEFAULT TRUE
 #endif
-   _set_string_var(".DIRCACHERESPCASE", DIRCACHERESPCASEDEFAULT, M_DEFAULT, &DcacheRespCase);
+   _set_bool_var  (".DIRCACHERESPCASE", DIRCACHERESPCASEDEFAULT, M_DEFAULT, &DcacheRespCase);
+#undef DIRCACHERESPCASEDEFAULT
 
    _set_string_var("MAKEDIR",Get_current_dir(),M_PRECIOUS|M_NOEXPORT,
 		   &Makedir_macval);
@@ -133,21 +140,20 @@ Create_macro_vars()
    _set_string_var("SPACECHAR", "x", M_PRECIOUS|M_NOEXPORT|M_FLAG, &Spacechar );
    Spacechar[0] = ' ';
 
-   _set_int_var( "MAXLINELENGTH", "0", M_DEFAULT|M_NOEXPORT, &Buffer_size );
-   _set_int_var( "PREP",          "0", M_DEFAULT, &Prep );
+   SET_INT_VAR_FROM_INT( "MAXLINELENGTH", 0, M_DEFAULT|M_NOEXPORT, &Buffer_size );
+   SET_INT_VAR_FROM_INT( "PREP",          0, M_DEFAULT, &Prep );
    (void) Def_macro("MAXLINELENGTH", "1024", M_FLAG | M_DEFAULT);
 
    /* MAXPROCESSLIMIT is overwritten by the ruletab.c settings. Set its
     * initial value high so that it allows MAXPROCESS to be changed
     * from the command line. */
-   _set_int_var( "MAXPROCESSLIMIT", "100", M_DEFAULT|M_NOEXPORT,&Max_proclmt );
+   SET_INT_VAR_FROM_INT( "MAXPROCESSLIMIT", 100, M_DEFAULT|M_NOEXPORT,&Max_proclmt );
 #if defined(USE_CREATEPROCESS)
    /* Set the OS early enough. */
    Max_proclmt = MAXIMUM_WAIT_OBJECTS;
 #endif
-   _set_int_var( "MAXPROCESS", "1", M_DEFAULT|M_NOEXPORT, &Max_proc );
-   sprintf(buf,"%d",NAME_MAX);
-   _set_int_var( "NAMEMAX", buf, M_DEFAULT|M_NOEXPORT, &NameMax);
+   SET_INT_VAR_FROM_INT("MAXPROCESS", 1, M_DEFAULT|M_NOEXPORT, &Max_proc );
+   SET_INT_VAR_FROM_INT("NAMEMAX", NAME_MAX, M_DEFAULT|M_NOEXPORT, &NameMax);
 }
 
 
@@ -169,6 +175,54 @@ int  *var;
    *var         = atoi(val);
 }
 
+/*
+** Define an integer variable value from an int, and set up the macro.
+** This is inteded for numeric constants, valstr should be the C litteral
+** string of val, aka #val
+*/
+static void
+_set_int_var_from_int_and_str(name, val, valstr, flag, var)
+char *name;
+int  val;
+char *valstr;
+int  flag;
+int  *var;
+{
+   HASHPTR hp;
+
+   hp = Def_macro(name, valstr, M_FLAG | flag);
+   hp->ht_flag |= M_VAR_INT | M_MULTI | M_INIT;
+   hp->MV_IVAR  = var;
+   *var         = val;
+}
+
+
+/*
+** Define an bool variable, and set up the macro.
+** Unlike _set_bit_var, this does not use global Glob_attr (Glob_attr's
+** bits are all used up anyway), and a bool takes 'Y' or 'y' as true, every
+** other string including NIL(char) are false, which is differnt from bit_var's
+** conversions to true and false. A bool is a global char var. Glob_attr could
+** be converted to a bit vector instead of being int32_t in the future but
+** the string to bool/bit conversion still needs a flag on whether its a
+** ""/NULL or 'y' conversion.
+*/
+static void
+_set_bool_var(name, val, flag, var)
+char *name;
+int  val;
+int  flag;
+char *var;
+{
+   HASHPTR hp;
+   char *valstr = val ? "y" : NIL(char);
+
+   hp = Def_macro(name, valstr, M_FLAG | flag);
+   hp->ht_flag |= M_VAR_BOOL | M_MULTI | M_INIT;
+   hp->MV_CVAR  = var;
+   *var         = val;
+}
+
 
 /*
 ** Define a string variables value, and set up the macro.
