@@ -1,6 +1,4 @@
-/* $RCSfile: make.c,v $
--- $Revision: 1.11.2.2 $
--- last change: $Author: vq $ $Date: 2008/02/04 21:05:42 $
+/*
 --
 -- SYNOPSIS
 --      Perform the update of all outdated targets.
@@ -31,7 +29,7 @@
 -- 
 --      This program is NOT free software; you can redistribute it and/or
 --      modify it under the terms of the Software License Agreement Provided
---      in the file <distribution-root>/readme/license.txt.
+--      in the file <distribution-root>/COPYING.
 --
 -- LOG
 --      Use cvs log to obtain detailed change logs.
@@ -251,8 +249,9 @@ Make_targets()/*
 
    for( lp = Targets->ce_prq; lp != NIL(LINK); lp = lp->cl_next ) {
       CELLPTR tgt = lp->cl_prq;
-      if( !(tgt->ce_attr & A_UPDATED) )
-	 printf( "`%s' is up to date\n", tgt->CE_NAME );
+      if( !(tgt->ce_attr & A_UPDATED) 
+          && (Verbose & V_MAKE) )
+          printf( "`%s' is up to date\n", tgt->CE_NAME );
    }
 
    DB_RETURN( 0 );
@@ -318,7 +317,9 @@ CELLPTR setdirroot;
    /* Set the UseWinpath variable to reflect the (global/local) .WINPATH
     * attribute. The variable is used by DO_WINPATH() and in some other
     * places. */
+#if defined(__CYGWIN__)
    UseWinpath = (((cp->ce_attr|Glob_attr)&A_WINPATH) != 0);
+#endif
 
    /* m_at needs to be defined before going to a "stop_making_it" where
     * a _drop_mac( m_at ) would try to free it. */
@@ -411,7 +412,7 @@ CELLPTR setdirroot;
 	 goto stop_making_it;
       }
       else if( cp->ce_prq != NIL(LINK)
-            || (STOBOOL(Augmake) && (cp->ce_flag&F_EXPLICIT)))
+            || (BTOBOOL(Augmake) && (cp->ce_flag&F_EXPLICIT)))
 	 /* Assume an empty recipe for a target that we have run inference on
 	  * but do not have a set of rules for but for which we have inferred
 	  * a list of prerequisites. */
@@ -429,9 +430,11 @@ CELLPTR setdirroot;
    /* Search the prerequisite list for dynamic prerequisites and if we find
     * them copy the list of prerequisites for potential later re-use. */
    if ( cp->ce_prqorg == NIL(LINK) ) {
-      for( dp = cp->ce_prq; dp != NIL(LINK); dp = dp->cl_next )
-	 if ( strchr(dp->cl_prq->CE_NAME, '$') != NULL )
+      for( dp = cp->ce_prq; dp != NIL(LINK); dp = dp->cl_next ) {
+         char * ce_name = dp->cl_prq->CE_NAME;
+	 if ( strchr(ce_name, '$') != NULL )
 	    break;
+      }
 
       if (dp != NIL(LINK)) {
 	 cp->ce_prqorg = _dup_prq(cp->ce_prq);
@@ -480,7 +483,9 @@ CELLPTR setdirroot;
       if (m_at->ht_value == NIL(char)) {
 	 /* This check effectively tests if Make() was run before because
 	  * Make() frees all dynamic macro values at the end. */
+#if defined(__CYGWIN__)
 	 UseWinpath = (((cp->ce_attr|Glob_attr)&A_WINPATH) != 0);
+#endif
 	 m_at = Def_macro("@", DO_WINPATH(cp->ce_fname), M_MULTI);
       }
 
@@ -526,7 +531,7 @@ CELLPTR setdirroot;
        * than one prerequisite. */
       /* A new A_DYNAMIC attribute could save a lot of strchr( ,'$') calls. */
       if ( tcp && !(tcp->ce_flag & F_MARK) && strchr(tcp->CE_NAME, '$') ) {
-	 /* Replace this dynamic prerequisite with the the real prerequisite,
+	 /* Replace this dynamic prerequisite with the real prerequisite,
 	  * and add the additional prerequisites if there are more than one.*/
 
 	 name = Expand( tcp->CE_NAME );
@@ -547,7 +552,7 @@ CELLPTR setdirroot;
 	 }
       }
 
-      /* Dynamic expansion results in a NULL cell only when the the new
+      /* Dynamic expansion results in a NULL cell only when the new
        * prerequisite is already in the prerequisite list or empty. In this
        * case delete the cell and continue. */
       if ( tcp == NIL(CELL) ) {
@@ -617,7 +622,7 @@ CELLPTR setdirroot;
        * replaced. */
       if( cp->ce_attr & A_LIBRARY )
 	 if( tcp->ce_time <= cp->ce_time ) {
-	    time_t mtime = Do_stat( name, tcp->ce_lib, NIL(char *), FALSE );
+	    time_t mtime = Do_stat( name, tcp->ce_lib, FALSE );
 	    if( mtime < tcp->ce_time ) tcp->ce_time = cp->ce_time+1L;
 	 }
 
@@ -647,7 +652,9 @@ CELLPTR setdirroot;
    if (m_at->ht_value == NIL(char)) {
       /* This check effectively tests if Make() was run before because
        * Make() frees all dynamic macro values at the end. */
+#if defined(__CYGWIN__)
       UseWinpath = (((cp->ce_attr|Glob_attr)&A_WINPATH) != 0);
+#endif
       m_at = Def_macro("@", DO_WINPATH(cp->ce_fname), M_MULTI);
    }
  
@@ -750,25 +757,26 @@ CELLPTR setdirroot;
       DB_PRINT( "make", ("Set ce_time (mintime) to: %ld", cp->ce_time) );
 
       if( Touch ) {
+	 if( !(cp->ce_attr & A_PHONY) && (!(Glob_attr & A_SILENT) || !Trace) ) {
 	 name = cp->ce_fname;
 	 lib  = cp->ce_lib;
 
-	 if( (!(Glob_attr & A_SILENT) || !Trace) && !(cp->ce_attr & A_PHONY) ) {
 	    if( lib == NIL(char) )
 	       printf("touch(%s)", name );
 	    else if( cp->ce_attr & A_SYMBOL )
 	       printf("touch(%s((%s)))", lib, name );
 	    else
 	       printf("touch(%s(%s))", lib, name );
-	 }
 
-	 if( !Trace && !(cp->ce_attr & A_PHONY) )
-	    if( Do_touch( name, lib,
-		(cp->ce_attr & A_SYMBOL) ? &name : NIL(char *) ) != 0 )
+	    if( !Trace )
+	       /* .SYMBOL feature is not implement for touch */
+	       if(cp->ce_attr & A_SYMBOL)
+	          Fatal("Library symbol names not supported");
+	       if( Do_touch( name, lib ) )
 	       printf( "  not touched - non-existant" );
 
-	 if( (!(Glob_attr & A_SILENT) || !Trace) && !(cp->ce_attr & A_PHONY) )
 	    printf( "\n" );
+	 }
 
 	 Update_time_stamp( cp );
       }
@@ -1043,6 +1051,7 @@ char *pat;
       cmp1 = DmStrPbrk(pfx,DirBrkStr);
       result = DmStrJoin(result,up,-1,TRUE);
    }
+   FREE(up);
 
    pat = DmStrSpn(pat,DirBrkStr);
    /* Append pat to result. */
@@ -1164,9 +1173,12 @@ _drop_mac( hp )/*
 ================ set a macro value to zero. */
 HASHPTR hp;
 {
-   if( hp && hp->ht_value != NIL(char) ) {
-      FREE( hp->ht_value );
+   if( hp ) {
+      char * value = hp->ht_value;
+      if( value != NIL(char) ) {
       hp->ht_value = NIL(char);
+         FREE( value );
+      }
    }
 }
 
@@ -1253,7 +1265,7 @@ Exec_commands( cp )/*
 
   The function returns 0, if the command is executed and has successfully
   returned, and it returns 1 if the command is executing but has not yet
-  returned or -1 if an error occured (Return value from Do_cmnd()).
+  returned or -1 if an error occurred (Return value from Do_cmnd()).
 
   Macros that are found in recipe lines are expanded in this function, in
   parallel builds this can mean they are expanded before the previous recipe
@@ -1352,8 +1364,10 @@ CELLPTR cp;
        * Nothing in Expand() should be able to change dynamic macros. */
       cmnd = Expand( rp->st_string );
 
-      if( new_attr && (p = DmStrSpn(cmnd," \t\n+-@%")) != cmnd )
-	 strcpy(cmnd,p);
+      if( new_attr && (p = DmStrSpn(cmnd," \t\n+-@%")) != cmnd ) {
+	 size_t len = strlen(p)+1;
+	 memmove(cmnd,p,len);
+      }
 
       /* COMMAND macro is set to "$(CMNDNAME) $(CMNDARGS)" by default, it is
        * possible for the user to reset it to, for example
@@ -1381,11 +1395,13 @@ CELLPTR cp;
 	 shell  = ((l_attr & A_SHELL) != 0);
 
 	 /* clean up the attributes that we may have just added. */
-	 if( (p = DmStrSpn(cmnd," \t\n+-@%")) != cmnd )
-	    strcpy(cmnd,p);
+	 if( (p = DmStrSpn(cmnd," \t\n+-@%")) != cmnd ) {
+	    size_t len = strlen(p)+1;
+	    memmove(cmnd,p,len);
+	 }
       }
 
-#if defined(MSDOS)
+#if defined(MSDOS) && defined(REAL_MSDOS)
       Swap_on_exec = ((l_attr & A_SWAP) != 0);	  /* Swapping for DOS only */
 #endif
       do_it = !Trace;
@@ -1477,8 +1493,9 @@ int  map;
    for( p=cmnd; *(n = DmStrPbrk(p,tmp)) != '\0'; )
       /* Remove the \<nl> sequences. */
       if(*n == CONTINUATION_CHAR && n[1] == '\n') {
+	 size_t len = strlen(n+2)+1;
 	 DB_PRINT( "make", ("fixing [%s]", p) );
-	 strcpy( n, n+2 );
+	 memmove( n, n+2, len );
 	 p = n;
       }
       /* Look for an escape sequence and replace it by it's corresponding
@@ -1513,7 +1530,6 @@ char *name;
 int  ignore;
 {
    STRINGPTR   new_dir;
-   int         freedir=FALSE;
 
    DB_ENTER( "Push_dir" );
 
@@ -1521,12 +1537,9 @@ int  ignore;
    if( *dir == '\'' && dir[strlen(dir)-1] == '\'' ) {
       dir = DmStrDup(dir+1);
       dir[strlen(dir)-1]='\0';
-      freedir=TRUE;
    }
-   else if (strchr(dir,'$') != NIL(char)) {
+   else if (strchr(dir,'$') != NIL(char))
       dir = Expand(dir);
-      freedir=TRUE;
-   }
    else
       dir = DmStrDup(dir);
 
@@ -1534,7 +1547,7 @@ int  ignore;
       if( !ignore )
          Fatal( "Unable to change to directory `%s', target is [%s]",
 	        dir, name );
-      if (freedir) FREE(dir);
+      FREE(dir);
       DB_RETURN( 0 );
    }
 
@@ -1542,7 +1555,7 @@ int  ignore;
    if( Verbose & V_DIR_SET )
       printf( "%s:  Changed to directory [%s]\n", Pname, dir  );
 
-   if (freedir) FREE( dir );
+   FREE( dir );
    TALLOC( new_dir, 1, STRING );
    new_dir->st_next   = dir_stack;
    dir_stack          = new_dir;
