@@ -1,4 +1,4 @@
-/* RCS  $Id: arlib.c,v 1.1.1.1 2000/09/22 15:33:27 hr Exp $
+/* RCS  $Id: arlib.c,v 1.1.1.1 2000-09-22 15:33:27 hr Exp $
 --
 -- SYNOPSIS
 --      Library access code.
@@ -18,7 +18,7 @@
 -- 
 --      This program is NOT free software; you can redistribute it and/or
 --      modify it under the terms of the Software License Agreement Provided
---      in the file <distribution-root>/readme/license.txt.
+--      in the file <distribution-root>/COPYING.
 --
 -- LOG
 --      Use cvs log to obtain detailed change logs.
@@ -37,7 +37,7 @@ char*	lib;
    	warned = TRUE,
    	Warning("Can't extract library member timestamp;\n\
    	using library timestamp instead.");
-   return (Do_stat(lib, NULL, NULL, TRUE));
+   return (Do_stat(lib, NULL, TRUE));
 }
 
 PUBLIC int
@@ -51,6 +51,6 @@ char*	lib;
    	warned = TRUE,
    	Warning("Can't update library member timestamp;\n\
    	touching library instead.");
-   return (Do_touch(lib, NULL, NULL));
+   return (Do_touch(lib, NULL));
 }
 
