@@ -1,4 +1,4 @@
-/* RCS  $Id: config.h,v 1.1.1.1.176.1 2007/11/11 00:03:32 vq Exp $
+/* RCS  $Id: config.h,v 1.2 2008-03-05 18:36:30 kz Exp $
 --
 -- SYNOPSIS
 --      Configurarion include file.
@@ -19,7 +19,7 @@
 -- 
 --      This program is NOT free software; you can redistribute it and/or
 --      modify it under the terms of the Software License Agreement Provided
---      in the file <distribution-root>/readme/license.txt.
+--      in the file <distribution-root>/COPYING.
 --
 -- LOG
 --      Use cvs log to obtain detailed change logs.
@@ -41,6 +41,8 @@ extern unsigned int coreleft();
 #   define MSDOS 1
 #endif
 
+#define REAL_MSDOS 1
+
 /* a small problem with pointer to voids on some unix machines needs this */
 #define DMPVOID void *
 
