@@ -1,4 +1,4 @@
-/* RCS  $Id: sysintf.h,v 1.4 2007/10/15 15:45:33 ihi Exp $
+/* RCS  $Id: sysintf.h,v 1.4 2007-10-15 15:45:33 ihi Exp $
 --
 -- SYNOPSIS
 --      Interfaces for sysintf.c
@@ -17,7 +17,7 @@
 -- 
 --      This program is NOT free software; you can redistribute it and/or
 --      modify it under the terms of the Software License Agreement Provided
---      in the file <distribution-root>/readme/license.txt.
+--      in the file <distribution-root>/COPYING.
 --
 -- LOG
 --      Use cvs log to obtain detailed change logs.
@@ -34,7 +34,7 @@ extern char * tempnam();
 extern char * getcwd();
 
 /* for directory cache */
-/* #define CacheStat(A,B)	really_dostat(A,&buf)*/
+/* #define CacheStat(A,B)	really_dostat(A)*/
 
 /*
 ** standard C items
@@ -46,7 +46,7 @@ extern char * getcwd();
 /* Disabled for CWS os2port01
  *#define	chdir(p) _dchdir(p)
  */
-#define CacheStat(A,B) really_dostat(A,&buf)
+#define CacheStat(A,B) really_dostat(A)
 
 /*
 ** make parameters
