@@ -1,6 +1,4 @@
-/* $RCSfile: stdmacs.h,v $
--- $Revision: 1.4.6.1 $
--- last change: $Author: vq $ $Date: 2005/04/22 04:22:27 $
+/*
 --
 -- SYNOPSIS
 --      General use macros.
@@ -22,7 +20,7 @@
 -- 
 --      This program is NOT free software; you can redistribute it and/or
 --      modify it under the terms of the Software License Agreement Provided
---      in the file <distribution-root>/readme/license.txt.
+--      in the file <distribution-root>/COPYING.
 --
 -- LOG
 --      Use cvs log to obtain detailed change logs.
