@@ -1,4 +1,4 @@
-/* RCS  $Id: sysintf.c,v 1.12.2.4 2008/02/07 19:50:01 vq Exp $
+/* RCS  $Id: sysintf.c,v 1.13 2008-03-05 18:30:58 kz Exp $
 --
 -- SYNOPSIS
 --      System independent interface
@@ -21,7 +21,7 @@
 --	the second group is ideally provided by the C lib.  However, there
 --	are instances where the C lib implementation of the specified routine
 --	does not exist, or is incorrect.  In these instances the routine
---	must be provided by the the user in the system/ directory of dmake.
+--	must be provided by the user in the system/ directory of dmake.
 --	(For example, the bsd/ dir contains code for putenv(), and tempnam())
 --
 --	DMAKE SPECIFIC:
@@ -53,7 +53,7 @@
 -- 
 --      This program is NOT free software; you can redistribute it and/or
 --      modify it under the terms of the Software License Agreement Provided
---      in the file <distribution-root>/readme/license.txt.
+--      in the file <distribution-root>/COPYING.
 --
 -- LOG
 --      Use cvs log to obtain detailed change logs.
@@ -61,15 +61,12 @@
 
 #include "extern.h"
 
-/* The following definition controls the use of GetModuleFileName() */
 #if defined(_MSC_VER) || defined(__MINGW32__)
-#   define HAVE_GETMODULEFILENAMEFUNC 1
-
 /* this is needed for the _ftime call below. Only needed here. */
 #   include <sys/timeb.h>
 #endif
 
-/* for cygwin_conv_to_posix_path() in Prolog() and for cygdospath()*/
+/* for cygwin_conv_path() in Prolog() and for cygdospath()*/
 #if __CYGWIN__
 #   include <sys/cygwin.h>
 #endif
@@ -91,62 +88,69 @@
 ** pointer pointed at by sym point at it.  Not handled for now!
 */
 static time_t
-really_dostat(name, buf)
+really_dostat(name)
 char *name;
-struct stat *buf;
 {
-   return( (   DMSTAT(name,buf)==-1 
-            || (STOBOOL(Augmake) && (buf->st_mode & S_IFDIR)))
+   DMPORTSTAT_T buf;
+   return( (   !DMPORTSTAT_SUCCESS(DMPORTSTAT(name,&buf))
+            || (BTOBOOL(Augmake) && DMPORTSTAT_ISDIR(&buf)))
 	   ? (time_t)0L
-	   : (time_t) buf->st_mtime
+	   : (time_t)DMPORTSTAT_MTIME(&buf)
 	 );
 }
 
+/* member is part of the unimplemented .SYMBOL feature, see DO_STAT in stat.c */
 
 PUBLIC time_t
-Do_stat(name, lib, member, force)
+Do_stat(name, lib, /*member,*/ force)
 char *name;
 char *lib;
-char **member;
+/*char **member;*/
 int  force;
 {
-   struct stat buf;
+   char * basename;
+   DMPORTSTAT_T buf;
    time_t seek_arch();
 
+/*
    if( member != NIL(char *) )
       Fatal("Library symbol names not supported");
+*/
 
-   buf.st_mtime = (time_t)0L;
+   basename = Basename(name);
    if( lib != NIL(char) )
-      return( seek_arch(Basename(name), lib) );
-   else if( strlen(Basename(name)) > NameMax ) {
+      return( seek_arch(basename, lib) );
+   else if( strlen(basename) > NameMax ) {
       Warning( "Filename [%s] longer than value of NAMEMAX [%d].\n\
-      Assume unix time 0.\n", Basename(name), NameMax );
+      Assume unix time 0.\n", basename, NameMax );
       return((time_t)0L);
    }
-   else if( STOBOOL(UseDirCache) )
+   else if( BTOBOOL(UseDirCache) )
       return(CacheStat(name,force));
    else
-      return(really_dostat(name,&buf));
+      return(really_dostat(name));
 }
 
 
 /* Touch existing file to force modify time to present.
  */
 PUBLIC int
-Do_touch(name, lib, member)
+Do_touch(name, lib/*, member*/)
 char *name;
 char *lib;
-char **member;
+/* char **member; */
 {
+   char * basename = Basename(name);
+/*
    if( member != NIL(char *) )
       Fatal("Library symbol names not supported");
+*/
 
    if (lib != NIL(char))
-      return( touch_arch(Basename(name), lib) );
-   else if( strlen(Basename(name)) > NameMax ) {
+      return( touch_arch(basename, lib) );
+   else if( strlen(basename) > NameMax ) {
       Warning( "Filename [%s] longer than value of NAMEMAX [%d].\n\
-      File timestamp not updated to present time.\n", Basename(name), NameMax );
+      File timestamp not updated to present time.\n", basename, NameMax );
       return(-1);
    }
    else
@@ -278,7 +282,7 @@ int     last;	/* Last recipe line in target. */
       DB_RETURN( 0 );
    }
 
-   /* Stop making the rest of the recipies for this target if an error occured
+   /* Stop making the rest of the recipes for this target if an error occurred
     * but the Continue (-k) flag is set to build as much as possible. */
    if ( target->ce_attr & A_ERROR ) {
       if ( last ) {
@@ -325,13 +329,17 @@ int    shell;
 char **cmd; /* Simulate a reference to *cmd. */
 {
    static char **av = NIL(char *);
+#if !defined(USE_CREATEPROCESS)
    static int   avs = 0;
+#endif
    int i = 0;
    char *s; /* Temporary string pointer. */
 
    if( av == NIL(char *) ) {
       TALLOC(av, MINARGV, char*);
+#if !defined(USE_CREATEPROCESS)
       avs = MINARGV;
+#endif
    }
    av[0] = NIL(char);
 
@@ -420,7 +428,6 @@ char *ename;
 }
 
 
-
 /*
 ** Set the value of the environment string ename to value.
 **  Returns 0 if success, non-zero if failure
@@ -430,18 +437,25 @@ Write_env_string(ename, value)
 char *ename;
 char *value;
 {
-   char*   p;
-   char*   envstr = DmStrAdd(ename, value, FALSE);
+#if defined(HAVE_SETENV)
 
-   p = envstr+strlen(ename);	/* Don't change this code, DmStrAdd does not */
-   *p++ = '=';			/* add the space if *value is 0, it does    */
-   if( !*value ) *p = '\0';	/* allocate enough memory for one though.   */
+  return( setenv(ename, value, 1) );
 
-   return( putenv(envstr) );
+#else  /* !HAVE_SETENV */
+
+  char*   p;
+  char*   envstr = DmStrAdd(ename, value, FALSE);
+
+  p = envstr+strlen(ename);	/* Don't change this code, DmStrAdd does not */
+  *p++ = '=';			/* add the space if *value is 0, it does    */
+  if( !*value ) *p = '\0';	/* allocate enough memory for one though.   */
+
+  return( putenv(envstr) ); /* Possibly leaking 'envstr' */
+
+#endif /* !HAVE_SETENV */
 }
 
 
-
 PUBLIC void
 ReadEnvironment()
 {
@@ -519,10 +533,9 @@ char* argv[];
 {
    Pname = (argc == 0) ? DEF_MAKE_PNAME : argv[0];
 
-   /* Only some native Windows compilers provide this functionality. */
-#ifdef HAVE_GETMODULEFILENAMEFUNC
-   if( (AbsPname = MALLOC( PATH_MAX, char)) == NIL(char) ) No_ram();
-   GetModuleFileName(NULL, AbsPname, PATH_MAX*sizeof(char));
+#ifdef _WIN32
+   /* get exe path from MS CRT's global buffer, CRT uses GetModuleFileName */
+   AbsPname = _pgmptr;
 #else
    AbsPname = "";
 #endif
@@ -532,14 +545,14 @@ char* argv[];
    if ( (CygDrvPre = MALLOC( PATH_MAX, char)) == NIL(char) )
       No_ram();
    else {
-      int err = cygwin_conv_to_posix_path("c:", CygDrvPre);
-      if (err)
+      int err = cygwin_conv_path(CCP_WIN_A_TO_POSIX, "c:", CygDrvPre, PATH_MAX);
+      if (err < 0)
 	 Fatal( "error converting \"%s\" - %s\n",
 		CygDrvPre, strerror (errno));
       if( (CygDrvPreLen = strlen(CygDrvPre)) == 2 ) {
-	 /* No prefix */
-	 *CygDrvPre = '\0';
-	 CygDrvPreLen = 0;
+	   /* No prefix */
+	   *CygDrvPre = '\0';
+	   CygDrvPreLen = 0;
       } else {
 	 /* Cut away the directory letter. */
 	 CygDrvPre[CygDrvPreLen-2] = '\0';
@@ -597,7 +610,7 @@ Get_current_dir()
    if( !getcwd(buf, sizeof(buf)) )
       Fatal("Internal Error: Error when calling getcwd()!");
 
-#ifdef __EMX__
+#ifdef __EMX__BACKSLASH
    char *slash;
    slash = buf;
    while( (slash=strchr(slash,'/')) )
@@ -731,7 +744,7 @@ Start_temp( suffix, cp, fname )/*
   created. This is done because the routines that create a save temporary
   file do not provide a definable suffix. The first (provided by Get_temp())
   is save and unique and the second file is generated by adding the desired
-  suffix the the first temporary file. The extra file is also linked to cp
+  suffix to the first temporary file. The extra file is also linked to cp
   so that it gets removed later.
   The function returns the FILE pointer to the temporary file (with suffix
   if specified) and leaves the file name in *fname.
@@ -1105,14 +1118,24 @@ CELLPTR cp;
 PUBLIC int
 Remove_file( name )
 char *name;
+/*
+ * Save some cycles. Avoid the stat() calls
+ */
 {
+#if 0
    struct stat buf;
 
    if( stat(name, &buf) != 0 )
       return 1;
    if( (buf.st_mode & S_IFMT) == S_IFDIR )
       return 1;
+#endif
+#ifdef _WIN32
+/* we dont need errno set, no callers check errno */
+   return !DeleteFile(name);
+#else
    return(unlink(name));
+#endif
 }
 
 
@@ -1138,8 +1161,8 @@ cygdospath(char *src, int winpath)/*
 
    if( *src && src[0] == '/' ) {
       char *tmp;
-      int err = cygwin_conv_to_win32_path(src, buf);
-      if (err)
+      int err = cygwin_conv_path(CCP_POSIX_TO_WIN_A, src, buf, PATH_MAX);
+      if (err < 0)
 	 Fatal( "error converting \"%s\" - %s\n",
 		src, strerror (errno));
 
