@@ -1,4 +1,4 @@
-/* RCS  $Id: sysintf.h,v 1.2 2007/01/18 09:43:39 vg Exp $
+/* RCS  $Id: sysintf.h,v 1.2 2007-01-18 09:43:39 vg Exp $
 --
 -- SYNOPSIS
 --      Interfaces for sysintf.c
@@ -17,7 +17,7 @@
 -- 
 --      This program is NOT free software; you can redistribute it and/or
 --      modify it under the terms of the Software License Agreement Provided
---      in the file <distribution-root>/readme/license.txt.
+--      in the file <distribution-root>/COPYING.
 --
 -- LOG
 --      Use cvs log to obtain detailed change logs.
@@ -29,7 +29,7 @@
 #define GETPID getpid()
 
 /* for directory cache */
-#define CacheStat(A,B)	really_dostat(A,&buf)
+#define CacheStat(A,B)	really_dostat(A)
 
 /*
 ** standard C items
