@@ -1,6 +1,4 @@
-/* $RCSfile: arlib.c,v $
--- $Revision: 1.4.6.2 $
--- last change: $Author: vq $ $Date: 2006/03/13 23:21:28 $
+/*
 --
 -- SYNOPSIS
 --      Unix archive manipulation code.
@@ -23,7 +21,7 @@
 -- 
 --      This program is NOT free software; you can redistribute it and/or
 --      modify it under the terms of the Software License Agreement Provided
---      in the file <distribution-root>/readme/license.txt.
+--      in the file <distribution-root>/COPYING.
 --
 -- LOG
 --      Use cvs log to obtain detailed change logs.
@@ -292,15 +290,15 @@ struct   ar_args *arg;
 
 #if ASCARCH
 #if defined(_AIX)
-   fread( (char *)&flhdr, sizeof(flhdr), 1, f );
+   if( fread( (char *)&flhdr, sizeof(flhdr), 1, f ) != 1 ) return (-1);
    if( strncmp(flhdr.fl_magic,AIAMAG, SAIAMAG) != 0 ) return(-1);
    fseek(f, atol(flhdr.fl_fstmoff), 0 ); /* postition to first member */
 #else
-   fread( magic, sizeof(magic), 1, f );
+   if( fread( magic, sizeof(magic), 1, f ) != 1 ) return( -1 );
    if( strncmp(magic, ARMAG, SARMAG) != 0 ) return( -1 );
 #endif
 #else
-   fread( (char*)&word, sizeof(word), 1, f );
+   if( fread( (char*)&word, sizeof(word), 1, f ) != 1 ) return( -1 );
    if( word != ARMAG ) return( -1 );
 #endif
 
