@@ -1,6 +1,4 @@
-/* $RCSfile: ruletab.c,v $
--- $Revision: 1.9 $
--- last change: $Author: ihi $ $Date: 2007/10/15 15:53:13 $
+/*
 --
 -- SYNOPSIS
 --      Default initial configuration of dmake.
@@ -20,7 +18,7 @@
 -- 
 --      This program is NOT free software; you can redistribute it and/or
 --      modify it under the terms of the Software License Agreement Provided
---      in the file <distribution-root>/readme/license.txt.
+--      in the file <distribution-root>/COPYING.
 --
 -- LOG
 --      Use cvs log to obtain detailed change logs.
