@@ -1,6 +1,4 @@
-/* $RCSfile: runargv.c,v $
--- $Revision: 1.13.2.9 $
--- last change: $Author: vq $ $Date: 2008/01/22 05:34:44 $
+/*
 --
 -- SYNOPSIS
 --      Invoke a sub process.
@@ -19,7 +17,7 @@
 -- 
 --      This program is NOT free software; you can redistribute it and/or
 --      modify it under the terms of the Software License Agreement Provided
---      in the file <distribution-root>/readme/license.txt.
+--      in the file <distribution-root>/COPYING.
 --
 -- LOG
 --      Use cvs log to obtain detailed change logs.
@@ -125,15 +123,19 @@ _finished_child(pid, status) [unix/runargv] handles the finished child. If
 #endif
 
 #if __CYGWIN__ && ENABLE_SPAWN
+#if HAVE_CYGWIN_PROCESS_H
+#  include <cygwin/process.h>
+#else
 #  include <process.h>
 #endif
+#endif
 
 #ifdef __EMX__
 #  include <process.h>
 #define _P_NOWAIT P_NOWAIT
 #endif
 
-#include "sysintf.h"
+#include <sysintf.h>
 #if HAVE_ERRNO_H
 #  include <errno.h>
 #else
@@ -269,9 +271,10 @@ dmwaitnext( wid, status )
 
    /* If ECHILD is set from waitpid/wait then no child was left. */
    if( *wid  == -1 ) {
+      int realErr = errno; // fprintf can pollute errno
       fprintf(stderr, "%s:  Internal Error: wait() failed: %d -  %s\n",
 	      Pname, errno, strerror(errno) );
-      if(errno != ECHILD) {
+      if( realErr != ECHILD ) {
 	 /* Wait was interrupted or a child was terminated (SIGCHLD) */
 	 return -2;
       } else {
@@ -369,9 +372,10 @@ dmwaitpid( pqid, wid, status )
    }
    /* If ECHILD is set from waitpid/wait then no child was left. */
    if( *wid  == -1 ) {
+     int realErr = errno; // fprintf can pollute errno
       fprintf(stderr, "%s:  Internal Error: waitpid() failed: %d -  %s\n",
 	      Pname, errno, strerror(errno) );
-      if(errno != ECHILD) {
+      if(realErr != ECHILD) {
 	 /* Wait was interrupted or a child was terminated (SIGCHLD) */
 	 return -2;
       } else {
@@ -438,7 +442,8 @@ private_strerror (errnum)
      int errnum; 
 { 
 #ifndef __APPLE__
-# if defined(arm32) || defined(linux) || defined(__FreeBSD__) || defined(__OpenBSD__)
+# if defined(arm32) || defined(linux) || defined(__FreeBSD__) || \
+     defined(__NetBSD__) || defined(__OpenBSD__) || defined(__DragonFly__)
   extern  const char * const sys_errlist[];
 # else
   extern  char *sys_errlist[];
@@ -515,7 +520,13 @@ char  **cmd; /* Simulate a reference to *cmd. */
    /* Return immediately for empty line or noop command. */
    if ( !*tcmd ||				/* empty line */
 	( strncmp(tcmd, "noop", 4) == 0 &&	/* noop command */
-	  (iswhite(tcmd[4]) || tcmd[4] == '\0')) ) {
+	  (iswhite(tcmd[4]) || tcmd[4] == '\0'))
+#ifdef MSDOS
+	||
+	( strncmp(tcmd, "rem", 3) == 0 &&	/* MSDOS/Win32 noop command */
+	  (iswhite(tcmd[3]) || tcmd[3] == '\0'))
+#endif
+	) {
       internal = 1;
    }
    else if( !shell &&  /* internal echo only if not in shell */
@@ -553,8 +564,11 @@ char  **cmd; /* Simulate a reference to *cmd. */
       /* Restore stdout/stderr if needed. */
       if( old_stdout != -1 ) {
 	 dup2(old_stdout, 1);
-	 if( old_stderr != -1 )
+	 close(old_stdout);
+	 if( old_stderr != -1 ) {
 	    dup2(old_stderr, 2);
+	    close(old_stderr);
+	  }
       }
 
       internal = 1;
@@ -571,7 +585,7 @@ char  **cmd; /* Simulate a reference to *cmd. */
 
    /* Really spawn or fork a child. */
 #if defined( USE_SPAWN )
-   /* As no other childs are started while the output is redirected this
+   /* As no other children are started while the output is redirected this
     * is save. */
    if( Is_exec_shell ) {
       /* Add error checking? */
@@ -593,8 +607,11 @@ char  **cmd; /* Simulate a reference to *cmd. */
 
    if( old_stdout != -1 ) {
       dup2(old_stdout, 1);
-      if( old_stderr != -1 )
+      close(old_stdout);
+      if( old_stderr != -1 ) {
 	 dup2(old_stderr, 2);
+	 close(old_stderr);
+      }
    }
    if(pid.pid == (DMHANDLE)-1) {
       /* spawn failed */
@@ -649,8 +666,11 @@ char  **cmd; /* Simulate a reference to *cmd. */
        * failed. */
       if( old_stdout != -1 ) {
 	 dup2(old_stdout, 1);
-	 if( old_stderr != -1 )
+	 close(old_stdout);
+	 if( old_stderr != -1 ) {
 	    dup2(old_stderr, 2);
+	    close(old_stderr);
+	 }
       }
       fprintf(stderr, "%s:  Error executing '%s': %s",
 	      Pname, argv[0], strerror(errno) );
@@ -769,7 +789,7 @@ int pqid;
 	       return 0;
 	    } else {
 	       Fatal( "dmake was interrupted or a child terminated. "
-		      "Stopping all childs ..." );
+		      "Stopping all children ..." );
 	    }
 	 } else {
 	    /* The child we were waiting for is missing or no child is
@@ -791,7 +811,7 @@ int pqid;
                }
 	       _proc_cnt = 0;
 	    }
-	    /* The pid we were waiting for or any of the remaining childs
+	    /* The pid we were waiting for or any of the remaining children
 	     * (pid == -1) is missing. This should not happen and means
 	     * that the process got lost or was treated elsewhere. */
 	    Fatal( "Internal Error: Child is missing but still listed in _procs[x] %d: %s\n"
@@ -828,8 +848,7 @@ int pqid;
 PUBLIC void
 Clean_up_processes()
 {
-   register int i;
-   int ret;
+   int i, ret;
 
    if( _procs != NIL(PR) ) {
       for( i=0; i<Max_proc; i++ )
@@ -869,41 +888,36 @@ int     wfc;
 
    /* Never change MAXPROCESS after _procs is allocated. */
    if( _procs_size != Max_proc ) {
-      /* If procs was never initialize this is OK, do it now. */
-      if( _procs == NIL(PR) ) {
-	 _procs_size = Max_proc;
-	 TALLOC( _procs, Max_proc, PR );
+     /* If procs was never initialize this is OK, do it now. */
+     if( _procs == NIL(PR) ) {
+       _procs_size = Max_proc;
+       TALLOC( _procs, Max_proc, PR );
 #if defined(USE_CREATEPROCESS)
-	 TALLOC( _wpList, Max_proc, HANDLE );
+       TALLOC( _wpList, Max_proc, HANDLE );
 
-	 /* Signed int values are cast to DMHANDLE in various places, use this
-	  * sanity check to verify that DMHANDLE is large enough. */
-	 if( sizeof(int) > sizeof(DMHANDLE) )
-	    Fatal( "Internal Error: Check type of DMHANDLE!" );
+       /* Signed int values are cast to DMHANDLE in various places, use this
+        * sanity check to verify that DMHANDLE is large enough. */
+       if( sizeof(int) > sizeof(DMHANDLE) )
+         Fatal( "Internal Error: Check type of DMHANDLE!" );
 #endif
-      }
-      else {
-	 Fatal( "MAXPROCESS changed from `%d' to `%d' after a command was executed!", _procs_size, Max_proc );
-      }
+     }
+     else {
+       Fatal( "MAXPROCESS changed from `%d' to `%d' after a command was executed!", _procs_size, Max_proc );
+     }
    }
 
    if( Measure & M_RECIPE )
       Do_profile_output( "s", M_RECIPE, target );
 
-   /* If _use_i!=-1 then this function is called by _finished_child()
-    * ( through runargv() ). */
+   /* If _use_i ! =-1 then this function is called by _finished_child() ( through runargv() ),
+      and we re-use the process queue number given by _use_i. */
    if( (i = _use_i) == -1 ) {
-      for( i=0; i<Max_proc; i++ )
-	 if( !_procs[i].pr_valid )
-	    break;
-   }
-   else {
-      /* Re-use the process queue number given by _use_i.
-       * Free the pointer before using it again below. */
-      FREE( _procs[i].pr_dir );
+     for( i=0; i<Max_proc; i++ )
+       if( !_procs[i].pr_valid )
+         break;
    }
 
-   pp = _procs+i;
+   pp = &(_procs[i]);
 
    pp->pr_valid  = 1;
    pp->pr_pid    = pid.pid;
@@ -912,7 +926,9 @@ int     wfc;
    pp->pr_ignore = ignore;
    pp->pr_last   = last;
    pp->pr_wfc    = wfc;
-   /* Freed above and after the last recipe in _finished child(). */
+
+   if( pp->pr_dir != NIL(char) )
+     FREE(pp->pr_dir);
    pp->pr_dir    = DmStrDup(Get_current_dir());
 
    Current_target = NIL(CELL);
@@ -944,80 +960,80 @@ _finished_child(cid, status)/*
 DMHANDLE cid;
 int	status;
 {
-   register int i;
-   char     *dir;
+  register int i;
+  char     *dir;
 
-   if((int)cid < 1) { /* Force int. */
-      /* internal command */
-      i = -((int)cid);
-   }
-   else {
-      for( i=0; i<Max_proc; i++ )
-	 if( _procs[i].pr_valid && _procs[i].pr_pid == cid )
+  if((int)cid < 1) { /* Force int. */
+    /* internal command */
+    i = -((int)cid);
+  }
+  else {
+    for( i=0; i<Max_proc; i++ )
+      if( _procs[i].pr_valid && _procs[i].pr_pid == cid )
 	    break;
 
-      /* Some children we didn't make esp true if using /bin/sh to execute a
-       * a pipe and feed the output as a makefile into dmake. */
-      if( i == Max_proc ) {
-	 Warning("Internal Warning: finished pid %d is not in pq!?", cid);
-	 return;
-      }
-   }
+    /* Some children we didn't make esp true if using /bin/sh to execute a
+     * a pipe and feed the output as a makefile into dmake. */
+    if( i == Max_proc ) {
+      Warning("Internal Warning: finished pid %d is not in pq!?", cid);
+      return;
+    }
+  }
 
-   /* Not a running process anymore, the next runargv() will not use
-    * _attach_cmd(). */
-   _procs[i].pr_valid = 0;
+  /* Not a running process anymore, the next runargv() will not use
+   * _attach_cmd(). */
+  _procs[i].pr_valid = 0;
 
-   if( Measure & M_RECIPE )
-      Do_profile_output( "e", M_RECIPE, _procs[i].pr_target );
+  if( Measure & M_RECIPE )
+    Do_profile_output( "e", M_RECIPE, _procs[i].pr_target );
 
-   _proc_cnt--;
-   dir = DmStrDup(Get_current_dir());
-   Set_dir( _procs[i].pr_dir );
+  _proc_cnt--;
+  dir = DmStrDup(Get_current_dir());
+  Set_dir( _procs[i].pr_dir );
 
-   if( _procs[i].pr_recipe != NIL(RCP) && !_abort_flg ) {
-      RCPPTR rp = _procs[i].pr_recipe;
+  if( _procs[i].pr_recipe != NIL(RCP) && !_abort_flg ) {
+    RCPPTR rp = _procs[i].pr_recipe;
 
 
-      Current_target = _procs[i].pr_target;
-      Handle_result( status, _procs[i].pr_ignore, FALSE, _procs[i].pr_target );
-      Current_target = NIL(CELL);
+    Current_target = _procs[i].pr_target;
+    Handle_result( status, _procs[i].pr_ignore, FALSE, _procs[i].pr_target );
+    Current_target = NIL(CELL);
 
-      if ( _procs[i].pr_target->ce_attr & A_ERROR ) {
-	 _procs[i].pr_last = TRUE;
-	 goto ABORT_REMAINDER_OF_RECIPE;
-      }
+    if ( _procs[i].pr_target->ce_attr & A_ERROR ) {
+      _procs[i].pr_last = TRUE;
+      goto ABORT_REMAINDER_OF_RECIPE;
+    }
 
-      _procs[i].pr_recipe = rp->prp_next;
+    _procs[i].pr_recipe = rp->prp_next;
 
-      _use_i = i;
-      /* Run next recipe line. The rp->prp_attr propagates a possible
-       * wfc condition. */
-      runargv( _procs[i].pr_target, rp->prp_group,
-	       rp->prp_last, rp->prp_attr, &rp->prp_cmd );
-      _use_i = -1;
+    _use_i = i;
+    /* Run next recipe line. The rp->prp_attr propagates a possible
+     * wfc condition. */
+    runargv( _procs[i].pr_target, rp->prp_group,
+             rp->prp_last, rp->prp_attr, &rp->prp_cmd );
+    _use_i = -1;
 
-      FREE( rp->prp_cmd );
-      FREE( rp );
+    FREE( rp->prp_cmd );
+    FREE( rp );
 
-      /* If all process queues are used wait for the next process to
-       * finish. Is this really needed here? */
-      if( _proc_cnt == Max_proc ) {
-	 Wait_for_child( FALSE, -1 );
-      }
-   }
-   else {
-      /* empty the queue on abort. */
-      if( _abort_flg )
-	 _procs[i].pr_recipe = NIL(RCP);
+    /* If all process queues are used wait for the next process to
+     * finish. Is this really needed here? */
+    if( _proc_cnt == Max_proc ) {
+      Wait_for_child( FALSE, -1 );
+    }
+  }
+  else {
+    /* empty the queue on abort. */
+    if( _abort_flg )
+      _procs[i].pr_recipe = NIL(RCP);
 
-      Handle_result(status,_procs[i].pr_ignore,_abort_flg,_procs[i].pr_target);
+    Handle_result(status,_procs[i].pr_ignore,_abort_flg,_procs[i].pr_target);
 
- ABORT_REMAINDER_OF_RECIPE:
-      if( _procs[i].pr_last ) {
-	 FREE(_procs[i].pr_dir ); /* Set in _add_child() */
+  ABORT_REMAINDER_OF_RECIPE:
+    if( _procs[i].pr_last ) {
+      FREE(_procs[i].pr_dir ); _procs[i].pr_dir = NIL(char); /* Set in _add_child() */
 
-	 if( !Doing_bang ) {
+      if( !Doing_bang ) {
 	    /* Update_time_stamp() triggers the deletion of intermediate
 	     * targets.  This starts a new process queue, so we have to
 	     * clear the _use_i variable. */
@@ -1026,12 +1042,12 @@ int	status;
 	    _use_i = -1;
 	    Update_time_stamp( _procs[i].pr_target );
 	    _use_i =  my_use_i;
-	 }
       }
-   }
+    }
+  }
 
-   Set_dir(dir);
-   FREE(dir);
+  Set_dir(dir);
+  FREE(dir);
 }
 
 
