@@ -1,4 +1,4 @@
-/* RCS  $Id: sysintf.h,v 1.4 2007/10/15 15:53:38 ihi Exp $
+/* RCS  $Id: sysintf.h,v 1.4 2007-10-15 15:53:38 ihi Exp $
 --
 -- SYNOPSIS
 --      Interfaces for sysintf.c
@@ -17,12 +17,15 @@
 -- 
 --      This program is NOT free software; you can redistribute it and/or
 --      modify it under the terms of the Software License Agreement Provided
---      in the file <distribution-root>/readme/license.txt.
+--      in the file <distribution-root>/COPYING.
 --
 -- LOG
 --      Use cvs log to obtain detailed change logs.
 */
 
+#ifdef _WIN32
+#  error This is unix/sysintf.h , this can not be included on Win32
+#endif
 #define DMSTAT stat
 #define VOID_LCACHE(l,m) (void) void_lcache(l,m)
 #define Hook_std_writes(A)
