@@ -1,4 +1,4 @@
-/* RCS  $Id: vextern.h,v 1.7 2007/10/15 15:42:04 ihi Exp $
+/* RCS  $Id: vextern.h,v 1.7 2007-10-15 15:42:04 ihi Exp $
 --
 -- SYNOPSIS
 --      Global variable declarations.
@@ -19,7 +19,7 @@
 -- 
 --      This program is NOT free software; you can redistribute it and/or
 --      modify it under the terms of the Software License Agreement Provided
---      in the file <distribution-root>/readme/license.txt.
+--      in the file <distribution-root>/COPYING.
 --
 -- LOG
 --      Use cvs log to obtain detailed change logs.
@@ -59,9 +59,9 @@ EXTERN	char*	Spacechar;	/* pointer to macro value for SPACECHAR   */
 EXTERN	char*	Keep_state;	/* current .KEEP_STATE file		  */
 EXTERN  char*   Escape_char;	/* Current escape character               */
 EXTERN  char*   LastMacName;	/* Last macro successfully parsed	  */
-EXTERN  char*   UseDirCache;    /* The value of .DIRCACHE                 */
-EXTERN  char*   DcacheRespCase; /* TRUE if we are to respect dcache case  */
-EXTERN  char*   OOoDmMode;	/* Enable special behavior for OOo build. */
+EXTERN  char    UseDirCache;    /* The value of .DIRCACHE                 */
+EXTERN  char    DcacheRespCase; /* TRUE if we are to respect dcache case  */
+EXTERN  char    OOoDmMode;	/* Enable special behavior for OOo build. */
 EXTERN	int	Target;		/* TRUE if a default target was found in  *
 				 * a makefile or on the commandline       */
 EXTERN	int	If_expand;	/* TRUE if calling Expand from getinp.c   */
@@ -74,9 +74,9 @@ EXTERN	int	Def_targets;	/* TRUE if defining targets - Only used	  *
 				 * in Def_cell().			  */
 EXTERN  int	Skip_to_eof;	/* TRUE if asked to skip to eof on input  */
 EXTERN	int	NameMax;	/* The value of NAMEMAX                   */
+#if __CYGWIN__
 EXTERN	int	UseWinpath;	/* True if .WINPATH is set for currently  *
 				 * made target.                           */
-#if __CYGWIN__
 EXTERN  char*   CygDrvPre;      /* Drive prefix used by cygwin            */
 EXTERN  int     CygDrvPreLen;   /* Drive prefix length used by cygwin     */
 #endif
@@ -94,7 +94,7 @@ EXTERN  int	zerofd;         /* File descriptor for /dev/null          */
 EXTERN  int	Doing_bang;	/* TRUE if target timestamp needs not to be
 				 * updated immediately. */
 EXTERN  int	Packed_shell;	/* TRUE if packed args to use a shell	  */
-#if defined(MSDOS)
+#if defined(MSDOS) && defined(REAL_MSDOS)
 EXTERN  int	Swap_on_exec;	/* TRUE if going to swap on exec call     */
 #endif
 EXTERN  int	State;		/* parser state				  */
@@ -103,7 +103,7 @@ EXTERN  int	Group;		/* parsing a group recipe ==> TRUE        */
 /* Command line option flags are defined here.  They correspond one-for one
  * with the flags defined in dmake.c */
  
-EXTERN	char    *Augmake;	  /* -A */
+EXTERN	char    Augmake;	  /* -A */
 EXTERN  char    Comment;	  /* -c */
 EXTERN	char	Get_env;	  /* -e or -E */
 EXTERN  char*   Notabs;		  /* -B */
@@ -116,7 +116,7 @@ EXTERN	int	Touch;		  /* -t */
 EXTERN	int	Check;		  /* -q */
 EXTERN	uint16	Verbose;	  /* -v */
 EXTERN	uint16	Measure;	  /* -m */
-EXTERN	int	Microsoft;	  /* -M */
+/*EXTERN	int	Microsoft;	  /* -M */
 EXTERN	int	Transitive;	  /* -T */
 EXTERN  int     No_exec;          /* -X */
 
