@@ -1,4 +1,4 @@
-/* RCS  $Id: sysintf.h,v 1.2.12.1 2006/09/30 15:01:17 vq Exp $
+/* RCS  $Id: sysintf.h,v 1.3 2007-01-18 09:49:31 vg Exp $
 --
 -- SYNOPSIS
 --      Interfaces for sysintf.c
@@ -17,7 +17,7 @@
 -- 
 --      This program is NOT free software; you can redistribute it and/or
 --      modify it under the terms of the Software License Agreement Provided
---      in the file <distribution-root>/readme/license.txt.
+--      in the file <distribution-root>/COPYING.
 --
 -- LOG
 --      Use cvs log to obtain detailed change logs.
@@ -39,7 +39,6 @@ extern char * getcwd();
 ** DOS interface standard items
 */
 #define	chdir(p) dchdir(p)
-#define CacheStat(A,B) really_dostat(A,&buf)
 
 /*
 ** make parameters
