@@ -1,4 +1,4 @@
-/* RCS  $Id: sysintf.h,v 1.2 2006/04/20 12:24:48 hr Exp $
+/* RCS  $Id: sysintf.h,v 1.3 2007-01-18 09:50:52 vg Exp $
 --
 -- SYNOPSIS
 --      Interfaces for sysintf.c
@@ -17,33 +17,38 @@
 -- 
 --      This program is NOT free software; you can redistribute it and/or
 --      modify it under the terms of the Software License Agreement Provided
---      in the file <distribution-root>/readme/license.txt.
+--      in the file <distribution-root>/COPYING.
 --
 -- LOG
 --      Use cvs log to obtain detailed change logs.
 */
 
 #define DMSTAT stat
+
+#define HAVE_DMPORTSTAT 1
+/* override default implementation */
+#undef DMPORTSTAT_T
+#undef DMPORTSTAT
+#undef DMPORTSTAT_SUCCESS
+#undef DMPORTSTAT_MTIME
+#undef DMPORTSTAT_ISDIR
+#define DMPORTSTAT_T WIN32_FILE_ATTRIBUTE_DATA
+#define DMPORTSTAT(path, buf) GetFileAttributesEx((path), GetFileExInfoStandard, (buf))
+#define DMPORTSTAT_SUCCESS(x) ((x) != 0)
+#define DMPORTSTAT_MTIME(x) (FileTimeTo_time_t(&((x)->ftLastWriteTime)))
+#define DMPORTSTAT_ISDIR(x) ((x)->dwFileAttributes & FILE_ATTRIBUTE_DIRECTORY)
+
 #define VOID_LCACHE(l,m)
 #define GETPID _psp
 #define Hook_std_writes(A)
-#define DMSTRLWR(A,B)  dstrlwr((A),(B))
 
 extern char * tempnam();
 extern char * getcwd();
 
-/* for directory cache */
-#define CacheStat(A,B)	really_dostat(A,&buf)
-
 /*
 ** standard C items
 */
 
-/*
-** DOS interface standard items
-*/
-#define	chdir(p) dchdir(p)
-
 /*
 ** make parameters
 */
