@@ -1,4 +1,4 @@
-/* RCS  $Id: config.h,v 1.8.2.3 2008/02/26 23:37:50 vq Exp $
+/* RCS  $Id: config.h,v 1.9 2008-03-05 18:41:51 kz Exp $
 --
 -- SYNOPSIS
 --      Configurarion include file.
@@ -19,7 +19,7 @@
 -- 
 --      This program is NOT free software; you can redistribute it and/or
 --      modify it under the terms of the Software License Agreement Provided
---      in the file <distribution-root>/readme/license.txt.
+--      in the file <distribution-root>/COPYING.
 --
 -- LOG
 --      Use cvs log to obtain detailed change logs.
@@ -27,7 +27,7 @@
 
 /* Name and version number of this package */
 #define PACKAGE "dmake"
-#define VERSION "4.12"
+#define VERSION "4.13.0"
 #define BUILDINFO "Windows / MS Visual C++"
 
 #if defined (_MSC_VER)
