@@ -1,4 +1,4 @@
-/* RCS  $Id: sysintf.h,v 1.3 2007/01/18 09:53:49 vg Exp $
+/* RCS  $Id: sysintf.h,v 1.3 2007-01-18 09:53:49 vg Exp $
 --
 -- SYNOPSIS
 --      Interfaces for sysintf.c
@@ -17,7 +17,7 @@
 -- 
 --      This program is NOT free software; you can redistribute it and/or
 --      modify it under the terms of the Software License Agreement Provided
---      in the file <distribution-root>/readme/license.txt.
+--      in the file <distribution-root>/COPYING.
 --
 -- LOG
 --      Use cvs log to obtain detailed change logs.
@@ -31,18 +31,10 @@
 extern char * tempnam();
 extern char * getcwd();
 
-/* for directory cache */
-#define CacheStat(A,B)	really_dostat(A,&buf)
-
 /*
 ** standard C items
 */
 
-/*
-** DOS interface standard items
-*/
-#define	chdir(p) dchdir(p)
-
 /* in sysintf.c: SIGQUIT is used, this is not defined in MinGW */
 #ifndef SIGQUIT
 #   define SIGQUIT SIGTERM
