@@ -1,4 +1,4 @@
-/* RCS  $Id: startup.h,v 1.1.1.1 2000/09/22 15:33:37 hr Exp $
+/* RCS  $Id: startup.h,v 1.2 2006-04-20 12:25:19 hr Exp $
 --
 -- SYNOPSIS
 --      Definition of MAKESTARTUP
@@ -18,12 +18,12 @@
 --
 --      This program is NOT free software; you can redistribute it and/or
 --      modify it under the terms of the Software License Agreement Provided
---      in the file <distribution-root>/readme/license.txt.
+--      in the file <distribution-root>/COPYING.
 --
 -- LOG
 --      Use cvs log to obtain detailed change logs.
 */
 
-/*"MAKESTARTUP := $(MAKECMD:d)startup/startup.mk",*/
+"DMAKEROOT *= $(ABSMAKECMD:d)startup",
 "MAKESTARTUP := $(DMAKEROOT)\\startup.mk",
 
